## AsperJS - Easy Media Query Generator
##### Formerly EasyQueryJS
---
### Installation
`npm install asperjs --save-dev`

### Usage
AsperJS can be instantiated and used in a variety of ways. In it's non-
parameterized form, it simply uses default values to generate your media 
query stylesheets. However, the other instantiation methods allow for 
more control over what is generated.

#### Default Values
```
{
    lang: 'scss',
    framework: 'bootstrap3',
    breakpoints: null // Loaded from 'bootstrap3' framework,
    buildCSS: true
}
```

Developers can be creative when it comes to how and where they use frame-
works like this; however, it's intended use is with build pipelines such
as Gulp or Grunt. See below for an example of usage with Gulp.

#### Non-Parameterized Use
`require('asperjs')();`

#### Framework Instantiation
When instantiating AsperJS, you may choose to pass the name of a 
supported framework as a parameter. If you do, it will autoload the 
prespecified media query breakpoints from that framework. See below for 
a list of supported frameworks.

`require('asperjs')('foundation5')`

#### Breakpoint Instantiation
To generate your own breakpoints without having to rely on a third-party 
framework's definitions, simply pass an array of breakpoints. These 
breakpoints can be numbers or strings. If you pass numbers, they will be 
treated as REM units by default; however, if you pass strings, they 
*must* be properly formatted as pixel, point, EM, or REM sizes with the 
unit of measurement included.

`require('asperjs')([20, 40, 75])`

or

`require('asperjs')(['768px', '972px', '1200px']);`

#### Object Parameter Instantiation
```
require('asperjs')({
    lang: 'scss',
    breakpoints: [20, 40, 75],
    buildCSS: true
})
```

### An Example Use of AsperJS with Gulp
```
require('asperjs')({lang: 'scss'});
 var gulp = require('gulp'),
     sass = require('gulp-sass');
 
 gulp.task('default', function() {
     gulp.src([ './app.scss' ])
     .pipe(sass())
     .pipe(gulp.dest('./'));
 });
 ```

### Supported Frameworks
- Bootstrap2 (as 'bootstrap2')
- Bootstrap3 (as 'bootstrap3')
- Bootstrap4 (as 'bootstrap4')
- Foundation5 (as 'foundation5')
- Foundation6 for Sites (as 'foundation6forsites')
- Foundation6 for Apps (as 'foundation6forapps')
- Foundation6 for Email (as 'foundation6foremail')
- Skeleton2 (as 'skeleton2')
- OpenFramework (as 'openframework')

### Supported Languages
- LessCSS (as 'less')
- SASS (as 'sass')
- SCSS (as 'scss')